@@ -17,7 +17,7 @@ pub fn spawn_integrate_dht_ops_consumer(
     cell_network: HolochainP2pCell,
 ) -> (TriggerSender, JoinHandle<ManagedTaskResult>) {
     let (tx, mut rx) = TriggerSender::new();
-    let mut trigger_self = tx.clone();
+    let trigger_self = tx.clone();
     let handle = tokio::spawn(async move {
         loop {
             // Wait for next job
