@@ -7,6 +7,7 @@ use crate::conductor::interface::SignalBroadcaster;
 use crate::core::queue_consumer::TriggerSender;
 use crate::core::ribosome::error::RibosomeError;
 use crate::core::ribosome::error::RibosomeResult;
+use crate::core::ribosome::guest_callback::post_commit::send_post_commit;
 use crate::core::ribosome::RibosomeT;
 use crate::core::ribosome::ZomeCallHostAccess;
 use crate::core::ribosome::ZomeCallInvocation;
@@ -62,11 +63,13 @@ pub async fn call_zome_workflow<Ribosome, C>(
 ) -> WorkflowResult<ZomeCallResult>
 where
     Ribosome: RibosomeT + Send + 'static,
-    C: CellConductorApiT,
+    C: CellConductorApiT + Clone,
 {
     let should_write = args.is_root_zome_call;
+    let conductor_api = args.conductor_api.clone();
     let result =
-        call_zome_workflow_inner(workspace.clone(), network.clone(), keystore, args).await?;
+        call_zome_workflow_inner(workspace.clone(), network.clone(), keystore.clone(), args)
+            .await?;
 
     // --- END OF WORKFLOW, BEGIN FINISHER BOILERPLATE ---
 
@@ -74,7 +77,8 @@ where
     if should_write {
         let is_empty = workspace.source_chain().is_empty()?;
         let countersigning_op = workspace.source_chain().countersigning_op()?;
-        workspace.flush(&network).await?;
+        let flushed_headers: Vec<(Option<Zome>, SignedHeaderHashed)> =
+            workspace.clone().flush(&network).await?;
         if !is_empty {
             match countersigning_op {
                 Some(op) => {
@@ -90,6 +94,8 @@ where
                 }
             }
         }
+
+        send_post_commit(conductor_api, workspace, network, keystore, flushed_headers).await?;
     }
 
     Ok(result)
