@@ -115,7 +115,7 @@ pub(crate) async fn countersigning_workflow(
 
     // For each complete session send the ops to validation.
     for (agents, ops, headers) in complete_sessions {
-        incoming_dht_ops_workflow(&env, None, sys_validation_trigger.clone(), ops, false).await?;
+        incoming_dht_ops_workflow(env, None, sys_validation_trigger.clone(), ops, false).await?;
         notify_agents.push((agents, headers));
     }
 
@@ -360,7 +360,7 @@ impl CountersigningWorkspace {
                         if session.map.values().all(|(_, _, required_hashes)| {
                             required_hashes
                                 .iter()
-                                .all(|hash| session.map.contains_key(&hash))
+                                .all(|hash| session.map.contains_key(hash))
                         }) {
                             Some(entry_hash.clone())
                         } else {
