@@ -358,6 +358,7 @@ mod tests {
                 // Create test env
                 let test_env = test_cell_env();
                 let env = test_env.env();
+                let zome = fixt!(Zome);
 
                 let dna = fixt!(DnaHash);
                 let filter_events = |evt: &_| match evt {
@@ -402,6 +403,7 @@ mod tests {
                 // Produces 3 ops but minus 1 for store entry so 2 ops.
                 let original_header_address = source_chain
                     .put(
+                        Some(zome.clone()),
                         builder::Create {
                             entry_type: ec_entry_type,
                             entry_hash: original_entry_hash.clone(),
@@ -415,6 +417,7 @@ mod tests {
                 // Produces 5 ops but minus 1 for store entry so 4 ops.
                 let entry_update_hash = source_chain
                     .put(
+                        Some(zome.clone()),
                         builder::Update {
                             entry_type: eu_entry_type,
                             entry_hash: new_entry_hash,
